##  Configuring Workspace Settings
You can configure workspace settings by navigating to the corresponding sections of the administration area. For an overview of settings, see [Workspace Settings Overview](https://help.sap.com/docs/leanix/ea/workspace-settings-overview?locale=en-US&state=PRODUCTION&version=CLOUD "Overview of settings available in the workspace administration area.").
To get started, you can do the following:
  * Customize branding settings: To align the workspace with your organization's brand identity, navigate to the Branding section in the administration area and make the necessary adjustments. To learn more, see [Branding](https://help.sap.com/docs/leanix/ea/branding-settings?locale=en-US&state=PRODUCTION&version=CLOUD "Personalize your workspace's appearance to reflect your brand identity or choose from one of the predefined workspace designs.").
  * Set the default language: Navigate to the General section in the administration area and select a language in the Default Language list. This action sets the default language for new users and existing users who haven't yet set their language preference. Users can change their workspace language in the user profile.
  * Configure notification settings: Configure default notification settings for workspace users. For more information, see [Notifications Center](https://help.sap.com/docs/leanix/ea/notifications-center?locale=en-US&state=PRODUCTION&version=CLOUD "Configure notification settings for your workspace."). Users can then adjust their notification preferences in the Notifications section.
  * Adjust other basic settings: You can start by adjusting settings in the General section and then proceed to customize other settings as per your organization's requirements.
